==> steganography_in_text-0.1.2.tar.gz: steganography_in_text-0.1.2/README.md <==
# Steganography_in_text

## Скрывайте свои тайны удобно!!!

------

<ul>
<li>
<a href="#Crypter">Работа с шифратором</a>
<ul>
<li>
<a href="#create_crypter">Создание шифратора</a>
</li>

<li>
<a href="#crypter_work">Создание шифров</a>
</li>
</ul>
</li>
<li>
<a href="#Decrypter">Работа с дешифратором</a>
<ul>
<li>
<a href="#create_decrypter">Создание дешифратора</a>
</li>

<li>
<a href="#decrypter_work">Расшифровка шифров</a>
</li>
</ul>
</li>
<li>
<a href="https://github.com/red-lexinus/steganography_progect">GitHub проекта</a>
</li>
</ul>



-----


<h3 id="Crypter" >Шифратор</h3>
<p id="create_crypter" style="white-space:pre-wrap;">
"""
Создадим наш шифратор
По умолчанию int_seed = 0
Он необходим для первичной перемешки
списка, необходимого для шифровки
Подробнее ниже
"""

from steganography_in_text import Crypter

crypter = Crypter()<br>
crypter = Crypter(int_seed)
</p>
<p id="crypter_work" style="white-space:pre-wrap;">
"""
А теперь давайте зашифруем ниши сообщения
sms - будет видно после шифрации, данное сообщение будет выступать обманкой
password - это пароль типа str
secret_message - наше секретное сообщение
"""

message = crypter.create_message(sms, password, secret_message)
</p>


---

<h3 id="Decrypter" >Дешифратор</h3>
<p id="create_decrypter" style="white-space:pre-wrap;">
"""
Создадим наш дешифратор
По умолчанию int_seed = 0
Он необходим для первичной перемешки
списка, необходимого для расшифровки
Подробнее ниже
"""

from steganography_in_text import Decrypter

decrypter = Decrypter()<br>
decrypter = Decrypter(int_seed)
</p>
<p id="decrypter_work" style="white-space:pre-wrap;">
"""
А теперь давайте расшифруем наши сообщения
sms - это сообщение в котором возможно есть шифровка
password  - это пароль типа str
"""

message = decrypter.create_message(sms, password)
</p>

==> steganography_in_text-0.1.3.tar.gz: steganography_in_text-0.1.3/README.md <==
# Steganography_in_text

## Скрывайте свои тайны удобно!!!

------

<ul>
<li>
<a href="#Crypter">Работа с шифратором</a>
<ul>
<li>
<a href="#create_crypter">Создание шифратора</a>
</li>

<li>
<a href="#crypter_work">Создание шифров</a>
</li>
</ul>
</li>
<li>
<a href="#Decrypter">Работа с дешифратором</a>
<ul>
<li>
<a href="#create_decrypter">Создание дешифратора</a>
</li>

<li>
<a href="#decrypter_work">Расшифровка шифров</a>
</li>
</ul>
</li>
<li>
<a href="https://github.com/red-lexinus/steganography_progect">GitHub проекта</a>
</li>
</ul>



-----


<h3 id="Crypter" >Шифратор</h3>
<p id="create_crypter" style="white-space:pre-wrap;">
"""
Создадим наш шифратор <br>
По умолчанию int_seed = 0 <br>
Он необходим для первичной перемешки <br>
списка, необходимого для шифровки <br>
Подробнее ниже <br>
"""

from steganography_in_text import Crypter

crypter = Crypter()<br>
crypter = Crypter(int_seed)
</p>
<p id="crypter_work" style="white-space:pre-wrap;">
"""<br>
А теперь давайте зашифруем ниши сообщения<br>
sms - будет видно после шифрации, данное сообщение будет выступать обманкой <br>
password - это пароль типа str <br>
secret_message - наше секретное сообщение <br>
""" <br>

message = crypter.create_message(sms, password, secret_message)
</p>


---

<h3 id="Decrypter" >Дешифратор</h3>
<p id="create_decrypter" style="white-space:pre-wrap;">
"""<br>
Создадим наш дешифратор<br>
По умолчанию int_seed = 0<br>
Он необходим для первичной перемешки<br>
списка, необходимого для расшифровки<br>
Подробнее ниже<br>
"""<br>

from steganography_in_text import Decrypter

decrypter = Decrypter()<br>
decrypter = Decrypter(int_seed)
</p>
<p id="decrypter_work" style="white-space:pre-wrap;">
"""<br>
А теперь давайте расшифруем наши сообщения<br>
sms - это сообщение в котором возможно есть шифровка<br>
password  - это пароль типа str<br>
"""<br>

message = decrypter.create_message(sms, password)
</p>
